""" Fichier barycentre.py """

import os
import re
from Bio.PDB import PDBList


def barycentres(id_pdb=""):

    """ barycentres des carbones alpha d'un fichier PDB """

    if id_pdb == "":
        print("syntaxe : barycentres(id_pdb) ")
        return

    pdbl = PDBList()
    pdbl.retrieve_pdb_file(id_pdb, pdir=".", file_format="pdb",
                                 overwrite=False)

    fichier = "pdb"+id_pdb.lower()+".ent"

    # test de la présence du fichier

    if not os.path.isfile(fichier):
        print("Aucun fichier PDB vu avec l'id "+id_pdb+".")
        return

    # parcours du fichier

    expr = re.compile(r"^ATOM\s+\d+\s+CA\s+[A-Z]+\s+([A-Z])\s+",
                                                  re.IGNORECASE)
    nb_lig = 0
    chaines = []
    carbones = []

    with open(fichier, "r", encoding="UTF-8") as pdb_fic:
        lignes = pdb_fic.readlines()

    for ligne in lignes:
        nb_lig += 1
        if expr.match(ligne):
            carbones.append(ligne.strip())
            res_rch = expr.search(ligne)
            chaine = res_rch.group(1)
            if chaine not in chaines:
                chaines.append(chaine)
    pdb_fic.close()

    print("-- Structure "+fichier, end=" : ")
    print(F" {nb_lig} lignes, {len(carbones)} acides aminés,", end="")
    print(F" {len(chaines)} chaine(s).")

    print("Chaine        AA  Coordonnées du barycentre")
    print("                      x       y       z")
    for chaine in chaines:
        nbaa = 0
        sum_coord = {'x': 0, 'y': 0, 'z': 0}
        for carbone in carbones:
            ligne = carbone.split()
            if ligne[4] == chaine:
                nbaa += 1
                sum_coord['x'] += float(ligne[6])
                sum_coord['y'] += float(ligne[7])
                sum_coord['z'] += float(ligne[8])
        print(F"   {chaine}  {nbaa:10d} ", end="")
        print(F" {sum_coord['x']/nbaa:7.2f}", end="")
        print(F" {sum_coord['y']/nbaa:7.2f}", end="")
        print(F" {sum_coord['z']/nbaa:7.2f} ")


if __name__ == "__main__":  # auto-test

    barycentres("")      # rappel de la syntaxe
    barycentres("NBT")   # structure inexistante
    barycentres("1BTA")  # structure existante  1 chaine
    barycentres("1ZNI")  # structure existante  4 chaines

# fin de l'auto-test
