""" Fichier disulfure.py """

import os
import re
from Bio.PDB import PDBList


def ponts_disulfures(id_pdb=""):

    """ recherche de ponts disulfures dans un fichier FASTA """

    if id_pdb == "":
        print("syntaxe : ponts_disulfures(id_pdb) ")
        return

    pdbl = PDBList()
    pdbl.retrieve_pdb_file(id_pdb, pdir=".", file_format="pdb",
                                 overwrite=False)
    fichier = "pdb" + id_pdb.lower() + ".ent"

    # test de la présence du fichier

    if not os.path.isfile(fichier):
        print("aucun fichier PDB avec l'id " + id_pdb + " vu ")
        return

    # parcours du fichier et affichages

    reg_pont = re.compile("^SSBOND", re.IGNORECASE)
    nb_ponts = 0
    nb_ligs = 0
    ponts = []
    with open(fichier, "r", encoding="UTF-8") as pdb_fic:
        lignes = pdb_fic.readlines()
    for ligne in lignes:
        nb_ligs += 1
        if reg_pont.match(ligne):
            nb_ponts += 1
            ponts.append(ligne.strip())
    pdb_fic.close()

    print("Structure "+fichier, end=" : ")
    print(F" {nb_ligs} lignes, {nb_ponts} ponts disulfures.")

    if nb_ponts > 0:
        print("Positions des cystéines impliquées",
                                      " dans ces ponts :")
        reg_org = r"^SSBOND\s+(\d+)\s+CYS\s+([A-Z0-9])\s+"
        reg_org += r"(\d+)\s+CYS\s+([A-Z])\s+(\d+)\s+"
        reg_pont = re.compile(reg_org)

        for pont in ponts:
            positn = [0, 0, 0]
            chaines = ["", "", ""]
            res_rch = reg_pont.search(pont)
            positn[0] = int(res_rch.group(1))
            positn[1] = int(res_rch.group(3))
            positn[2] = int(res_rch.group(5))
            chaines[0] = res_rch.group(2)
            chaines[1] = res_rch.group(4)
            if chaines[0] == chaines[1]:
                chaines[2] = "intra"
            else:
                chaines[2] = "inter"
            print(F"pont {positn[0]:3d} ({chaines[2]}) ", end="")
            print(F" chaine {chaines[0]} position {positn[1]:4d}",
                                                        end="")
            print(F" chaine {chaines[1]} position {positn[2]:4d}")


if __name__ == "__main__":  # auto-test

    ponts_disulfures()        # rappel de la syntaxe
    ponts_disulfures("NBT")   # structure inexistante
    ponts_disulfures("1fat")  # structure sans ponts disulfure
    ponts_disulfures("6TAV")  # structure avec 45 ponts disulfure

# fin de l'auto-test
