""" Fichier gctm.py """


def gc_tm(sequence):

    """ calcul de %GC et de Tm """

    sequence = sequence.upper()  # conversion silencieuse

    compteurs_nuc = {}
    for nucleotide in ['A', 'T', 'G', 'C']:
        compteurs_nuc[nucleotide] = sequence.count(nucleotide)

    nb_gc = compteurs_nuc['G'] + compteurs_nuc['C']
    nb_at = compteurs_nuc['A'] + compteurs_nuc['T']
    nb_nucleotides = nb_gc + nb_at

    pct_gc = 100*nb_gc / nb_nucleotides
    if nb_nucleotides < 13:
        tm_val = (2*nb_at) + (4*nb_gc)
    else:
        tm_val = 64.9 + 41.0*(nb_gc-16.4)/(nb_gc+nb_at)

    return {'compteurs': compteurs_nuc,
               'pct_gc': pct_gc, 'tm': tm_val}


if __name__ == "__main__":  # auto-test

    # test des deux formules de Tm,
    # respectivement longueur < 13 et longueur > 13

    SEQ1 = "GATTACA"
    print(F"Voici ce que produit gc_tm('{SEQ1}') : ",
       gc_tm(SEQ1))

    SEQ2 = 'CGTTCCAAAGATGTGGGCATGAGCTTAC'
    print(F"Voici ce que produit gc_tm('{SEQ2}') : ",
       gc_tm(SEQ2))

    # pour vérifier l'exemple de la figure 1.3

    XMP = "AGGGAAAGAGCCCGCGCTCCTCGGCGCGAATAGAGAAG"
    print(gc_tm(XMP))

# fin de l'auto-test
