""" Fichier homologues_utils.py """

from Bio import SeqIO
from Bio import Entrez
from Bio.Blast import NCBIWWW
from Bio.Blast import NCBIXML


def lecture_fasta(nom_fic_fasta):

    """ lecture d'un fichier fasta local """

    print(F"  - lecture du fichier {nom_fic_fasta} réussie")
    sequence = next(SeqIO.parse(nom_fic_fasta, 'fasta'))
    fasta_rec = ">" + sequence.id + "\n" + sequence.seq

    return fasta_rec


def fasta_from_entrez(num_acc, nom_fic_fasta):

    """ lecture d'une séquence fasta via Entrez ;
        on passage on écrit le fichier local correspondant """

    # recherche de la correspondance entre numéro d'accession
    # et numéro identifiant

    Entrez.email = "Your.Name.Here@example.org"
    rec = Entrez.read(Entrez.esearch(db="protein", term=num_acc))
    id_num = rec['IdList']

    # récupération de l'identifiant complet et
    # de la séquence associée au format Fasta

    handle = Entrez.efetch(db="protein", id=id_num,
                         rettype="fasta", retmode="text")
    fasta_id = handle.readline()
    fasta_seq = handle.readline()
    handle.close()
    fasta_rec = fasta_id + fasta_seq
    with open(nom_fic_fasta, "w", encoding="UTF-8") as fasta_file:
        fasta_file.write(fasta_rec)
    print(F"  - écriture du fichier {nom_fic_fasta} réussie")

    return fasta_rec


def xml_from_blastp(fasta_rec, motif_pr, nb_hom, nom_fic_xml):

    """ requete blast et écriture du fichier XML """

    print(F"motif {motif_pr} ")
    print(F"fichier de résultats {nom_fic_xml}", end="")

    print("FASTAREC pour PHI-BLAST:")
    print(fasta_rec)

    result_handle = NCBIWWW.qblast(
         program="blastp", database="nr",
         sequence=fasta_rec, phi_pattern=motif_pr,
         hitlist_size=nb_hom)

    # sauvegarde du fichier XML des résultats

    blast_results = result_handle.read()
    with open(nom_fic_xml, 'w', encoding='UTF-8') as save_file:
        save_file.write(blast_results)

    print(F"  - écriture du fichier {nom_fic_xml} réussie")


def parcours_xml(nom_fic_xml, nb_hom):

    """ parcours XML et extraction des HSP """

    tab_res = []
    with open(nom_fic_xml, "r", encoding="UTF-8") as fic_xml:
        for record in NCBIXML.parse(fic_xml):
            if record.alignments:
                nb_ali = 0
                for align in record.alignments:
                    nb_ali += 1
                    if nb_ali <= nb_hom:
                        nb_hsp = 0
                        for hsp in align.hsps:
                            nb_hsp += 1
                            tab_res.append({'idprot': align.hit_id,
                              'evalue': hsp.expect, 'escore': hsp.score})

    print(F"  - lecture du fichier {nom_fic_xml} réussie")

    return tab_res
