""" Fichier profilhyd_biopython.py """

import re
from Bio.SeqUtils.ProtParam import ProteinAnalysis, ProtParamData
from profilhyd_utils import sequence_fichier, sequence_uniprot


def profil_hydro(fic_ou_uniprot, taille):

    """ profil d'hydrophocité d'une protéine
        au format FASTA en local ou sur Uniprot """

    print("Profil d'hydrophobicité, protéine ",
          fic_ou_uniprot + " fenêtre taille " + str(taille))

    # si le paramètre fic_ou_uniprot finit par "fasta",
    # c'est un fichier local ;
    # sinon, c'est un identifiant pour Uniprot

    if re.search("fasta$", fic_ou_uniprot):
        sequence = sequence_fichier(fic_ou_uniprot)
    else:
        sequence = sequence_uniprot(fic_ou_uniprot)

    nb_res = len(sequence)

    if nb_res <= 0:
        print(F"La séquence associée à {fic_ou_uniprot} est vide.")
        print("STOP.")
        return ""

    # calcul de l'hydrophobicité moyenne par fenêtre

    analyse = ProteinAnalysis(str(sequence))
    hydrophobicite = analyse.protein_scale(window=taille,
                          param_dict=ProtParamData.kd)

    if nb_res < 10:
        print(hydrophobicite)
    else:
        print(hydrophobicite[:6])

    return hydrophobicite


if __name__ == "__main__":   # auto-test

    profil_hydro("BABG.fasta", 7)      # fichier non vu
    profil_hydro("P12345678", 7)       # URL non vue
    profil_hydro("IVLFCMAG.fasta", 7)  # fichier présent
    profil_hydro("P11229", 21)         # URL vue

# fin de l'auto-test
