""" Fichier ramachandran.py """

import os
import Bio.PDB
from Bio.PDB.PDBParser import PDBParser
from ramachandran_utils import ligne_titre, \
                     analyse_res, rama_diagram


def ramachandran(id_pdb=""):

    """ diagrammes de Ramachandan d'un fichier-structure
                                               de la PDB """

    if id_pdb == "":
        print("syntaxe : ramachandran(id_pdb) ")
        return
    pdbl = Bio.PDB.PDBList()
    pdbl.retrieve_pdb_file(id_pdb, pdir=".", file_format="pdb",
                                 overwrite=False)
    fichier = "pdb"+id_pdb.lower()+".ent"

    # test de la présence du fichier

    if not os.path.isfile(fichier):
        print("aucun fichier PDB avec l'id "+id_pdb+" vu ")
        return

    nbl_titre = ligne_titre(fichier)

    # récupération des chaines polypeptidiques

    decoupage = PDBParser()
    structure = decoupage.get_structure('codePDB', fichier)
    premier_modele = structure[0]
    lst_chaines = premier_modele.child_dict
    nb_chaines = len(lst_chaines)

    print(F"-- Protéine {fichier} : {nbl_titre[0]} lignes")
    print(F" {nbl_titre[1]} ")
    print(F" {nb_chaines} chaines polypeptidiques")

    for lettre in lst_chaines.keys():
        print(lettre+" ", end="")
    print()

    coord = analyse_res(structure)  # analyse des résidus
    rama_diagram(coord)             # représentation graphique


if __name__ == "__main__":  # auto-test

    ramachandran("")       # rappel de la syntaxe
    ramachandran("ldw")    # structure inexistante
    ramachandran("5ldw")   # structure existante

# fin de l'auto-test
