""" Fichier rchmotif3.py """

import os
import re
from io import StringIO
import requests
from Bio import SeqIO


def rch_motif(fic="", reg_exp=""):

    """ rch_motif : recherche de motifs
        dans des séquences Fasta  """

    if fic == "":
        print("syntaxe : rchMotif(fichier, expressionReguliere)")
        return

    if fic[0:7] == "http://":
        data = requests.get(fic, timeout=20).text
        records = list(SeqIO.parse(StringIO(data), "fasta"))
    else:
        if not os.path.isfile(fic):
            print(" fichier " + fic + " non vu")
            return
        records = list(SeqIO.parse(fic, "fasta"))
    print(F"sur les {len(records)} séquences du fichier {fic}")

    try:
        expr = re.compile(reg_exp, re.IGNORECASE)
    except re.error:
        print("Expression régulière incorrecte.STOP")
        return

    ind_seq = -1
    seqm = []
    for seqc in records:
        ind_seq += 1
        laseq = seqc.seq
        if expr.match(str(laseq)):
            seqm.append(ind_seq)

    print(F"{len(seqm)} séquences correspondent à {reg_exp} :")

    for indq in seqm:
        id_seq = records[indq].id
        print(F"  séquence {(1+indq):2d} id = { id_seq } ")


if __name__ == "__main__":  # auto-test

    rch_motif("")
    rch_motif("proteines.fasta", "^MSQE")
    URLFASTA = "http://gilles-hunault.leria-info.univ-angers.fr/Pyeg/"
    URLFASTA = URLFASTA + "proteines.fasta"
    rch_motif(URLFASTA, "^MSQE")

# fin de l'auto-test
