""" Fichier repliement.py """

import os
import re
import json
import requests
from Bio import SeqIO


# code get_foldindex importé du site de foldindex
#      https://fold.proteopedia.org/cgi-bin/findex
#      références du code :

__author__ = "Jaime Prilusky"
__year__ = "2021"
__version__ = "1.02"


def get_foldindex(seq):

    """ calcul du foldindex d'une séquence """

    seq = re.sub(r"\W", '', seq)
    url = "https://fold.proteopedia.org/cgi-bin/findex?m=json&sq=" + seq
    req = requests.get(url, timeout=15)
    data = json.loads(req.text)

    return data["findex"]


def foldindex_fasta(fasta_filename):

    """ calcul du foldindex des protéines d'un fichier Fasta """

    if not os.path.isfile(fasta_filename):
        print('fichier "' + fasta_filename + '" non vu. STOP.')
        return

    prot_fi = {}
    with open(fasta_filename, "r", encoding="UTF-8") as fasta_file:
        for record in SeqIO.parse(fasta_file, "fasta"):
            seq = str(record.seq)
            findex = get_foldindex(seq)
            prot_fi[record.id] = findex
    prot_fi = dict(sorted(prot_fi.items(),
                          key=lambda x: x[1]))
    print("Indices de repliement, fichier "+fasta_filename)
    print("Protéine    FoldIndex")
    for prot_id in prot_fi:
        print(F"{prot_id:15} {prot_fi[prot_id]:5.3f}")


if __name__ == "__main__":   # auto-test

    foldindex_fasta("nonvu.fasta")      # fichier non vu
    foldindex_fasta("proteines.fasta")  # fichier présent

# fin de l'auto-test
