""" Fichier superp.py """

import Bio.PDB
from superp_pdb import lecture_ca_pdb, atomes_region_aa


def superp(id_pdb1="", id_pdb2="", debut_aa=0, fin_aa=0):

    """ superposition des structures de deux protéines """

    if id_pdb1 == "":
        print("syntaxe :  superp(id_pdb1,id_pdb2,debut_aa,fin_aa)")
        return

    stru1 = lecture_ca_pdb(id_pdb1)
    stru2 = lecture_ca_pdb(id_pdb2)
    if not (stru1[0] == 0 and stru2[0] == 0):
        print("erreur de lecture PDB. STOP")
        return

    region_aa = range(debut_aa, fin_aa+1)
    if region_aa == range(0, 1):
        print("séquence AA incorrecte, valeurs fournies :",
             debut_aa, fin_aa)
        return

    atomes1 = atomes_region_aa(stru1[1], region_aa)
    atomes2 = atomes_region_aa(stru2[1], region_aa)

    # si on arrive ici, le calcul est sans doute possible

    superposition = Bio.PDB.Superimposer()
    superposition.set_atoms(atomes1, atomes2)
    superposition.apply(stru1[1].get_atoms())
    rmsd_arrondi = round(superposition.rms, 3)
    print(F"Superposition des carbones alpha des 2 structures : \
            RMSD = {rmsd_arrondi} A")
    print(F" pour les positions {debut_aa} à {fin_aa}")
    print("remarque : plus la valeur RMSD est faible, \
          meilleure est la superposition des structures.")


if __name__ == "__main__":  # auto-test

    superp()               # rappel de la syntaxe
    superp("1UBQ")         # structure manquante
    superp("1UBQ", "ABCD")  # structure inexistante
    superp("1UBQ", "1D3Z")  # structures existantes sans positions
    superp("1UBQ", "1D3Z", 1, 76)  # structures OK, positions correctes
    superp("1BTA", "4D7J", 5, 20)  # structures OK, positions correctes

# fin de l'auto-test
